ClientOnly class final

A component explicitly marked as browser-only.

The SSR analyzer will not flag browser-only API usage inside it.

Constructors

ClientOnly({Type? fallback})
const

Properties

fallback Type?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited