EffectCleanup typedef
EffectCleanup =
void Function()
A callback returned by an effect to clean up its subscription.
Implementation
typedef EffectCleanup = void Function();
A callback returned by an effect to clean up its subscription.
typedef EffectCleanup = void Function();