forwardedCurrent property
Object?
get
forwardedCurrent
The current value of the Dart ref supplied by the caller, if any.
Implementation
Object? get forwardedCurrent;
The current value of the Dart ref supplied by the caller, if any.
Object? get forwardedCurrent;