renderIdentity property
Function
get
renderIdentity
The render callback identity used to cache the React component type.
Implementation
Function get renderIdentity;
The render callback identity used to cache the React component type.
Function get renderIdentity;