Fragment class final

Groups children without adding a host element.

See https://react.dev/reference/react/Fragment.

Inheritance

Constructors

Fragment(List<ReactNode> children, {String? key})
const

Properties

children List<ReactNode>
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited