HostNode<P extends Object?> class final

Inheritance

Constructors

HostNode(HostType<P> type, P props, {List<ReactNode> children = const [], String? key})
const

Properties

children List<ReactNode>
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
props → P
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HostType<P>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited