LazyComponent<P> class final

A lazily loaded component definition.

See https://react.dev/reference/react/lazy.

Constructors

LazyComponent(LazyComponentLoader<P> load)
Creates a lazy component.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
load LazyComponentLoader<P>
Loads the component implementation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(P props, {String? key}) ReactNode
Creates a node that suspends until load resolves.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited