LazyNodeBase class abstract interface

The renderer-facing erased form of a lazy node.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
loaderIdentity Function
The loader identity used to cache the React lazy component type.
no setter
nodeKey String?
The optional React key.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWithErased(Object builder) ReactNode
Builds the typed component through an erased bridge.
loadErased() Future<Object>
Loads the typed builder through an erased bridge.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited