loaderIdentity property
Function
get
loaderIdentity
The loader identity used to cache the React lazy component type.
Implementation
Function get loaderIdentity;
The loader identity used to cache the React lazy component type.
Function get loaderIdentity;