useStateWithUpdater<T> method
Reads state with a setter that also accepts functional updates.
Implementation
(T, StateSetter<T>) useStateWithUpdater<T>(T initial) =>
unsupportedReactFeature('useState (functional updates)');
Reads state with a setter that also accepts functional updates.
(T, StateSetter<T>) useStateWithUpdater<T>(T initial) =>
unsupportedReactFeature('useState (functional updates)');