ReactChildren typedef

ReactChildren = Iterable<Object?>

Values accepted by ergonomic React child APIs.

Renderers continue to receive a normalized List of ReactNode values. This input type intentionally accepts nested iterables so ordinary Dart collection-if, collection-for, and spread expressions remain convenient.

Implementation

typedef ReactChildren = Iterable<Object?>;