call method
Creates a component node with typed props and children.
Implementation
ReactNode call(P props, {ReactChildren children = const [], String? key}) =>
Component(id, props, children: normalizeChildren(children), key: key);
Creates a component node with typed props and children.
ReactNode call(P props, {ReactChildren children = const [], String? key}) =>
Component(id, props, children: normalizeChildren(children), key: key);