ReactContext<T> class final

A React context definition and its default value.

See https://react.dev/reference/react/createContext.

Constructors

ReactContext(T defaultValue)
Creates a context with defaultValue.
const

Properties

defaultValue → T
The value used when no provider is above the component.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provider(T value, ReactChildren children) ReactNode
Creates a provider node for this context.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited