defaultValue property
T
defaultValue
final
The value used when no provider is above the component.
Implementation
final T defaultValue;
The value used when no provider is above the component.
final T defaultValue;