ReactRef<T> class final

A mutable object ref whose identity is stable for the lifetime of a hook.

See https://react.dev/reference/react/useRef.

Constructors

ReactRef([T? current])
Creates a ref with current as its initial value.
ReactRef.linked(T? current, void onChanged(T?))
Creates a ref whose writes are mirrored to onChanged.

Properties

current ↔ T?
The value currently stored in the ref.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited