ReactRuntime class final

Constructors

ReactRuntime({required ReactRenderTarget target, required ReactRuntimeCapabilities capabilities, required ReactBinding binding, required ReactRenderer renderer})
const

Properties

binding ReactBinding
final
capabilities ReactRuntimeCapabilities
final
hashCode int
The hash code for this object.
no setterinherited
renderer ReactRenderer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target ReactRenderTarget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited