ReactRuntimeCapabilities class final

Constructors

ReactRuntimeCapabilities({required bool supportsEvents, required bool supportsRefs, required bool supportsEffects, bool supportsLayoutEffects = false, bool supportsContext = false, bool supportsSuspense = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsContext bool
final
supportsEffects bool
final
supportsEvents bool
final
supportsLayoutEffects bool
final
supportsRefs bool
final
supportsSuspense bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited