ReactValueKind enum

Categories of values that can be passed through the React callback bridge.

Inheritance
Available extensions

Values

void_ → const ReactValueKind

No value.

any → const ReactValueKind

Any JavaScript value.

string → const ReactValueKind

A JavaScript string.

integer → const ReactValueKind

A JavaScript integer.

number → const ReactValueKind

A JavaScript number.

boolean → const ReactValueKind

A JavaScript boolean.

reactNode → const ReactValueKind

A rendered React node.

hostValue → const ReactValueKind

A value owned by a renderer.

Examples:

  • a browser Event or Element
  • a React synthetic event object
  • a future native-renderer handle
encodedObject → const ReactValueKind

Structured application data converted through a registered codec.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReactValueKind>
A constant List of the values in this enum, in order of their declaration.