Suspense class final

A node that displays fallback while its children suspend.

See https://react.dev/reference/react/Suspense.

Inheritance

Constructors

Suspense({required ReactNode fallback, required List<ReactNode> children})
Creates a Suspense boundary.
const

Properties

children List<ReactNode>
The content that may suspend.
final
fallback ReactNode
The content shown while children are suspended.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited