unsupportedReactFeature function
Throws a consistent error for a runtime feature that is only stubbed.
Implementation
Never unsupportedReactFeature(String feature) =>
throw UnsupportedError('$feature is not implemented by this renderer yet.');
Throws a consistent error for a runtime feature that is only stubbed.
Never unsupportedReactFeature(String feature) =>
throw UnsupportedError('$feature is not implemented by this renderer yet.');