useId function
Returns a stable identifier suitable for matching server and client trees.
Implementation
String useId() => currentReactRuntime.binding.useId();
Returns a stable identifier suitable for matching server and client trees.
String useId() => currentReactRuntime.binding.useId();