ContextProvider<T> class
final
A provider node for context.
See https://react.dev/reference/react/createContext#provider.
Constructors
-
ContextProvider(ReactContext<
T> context, T value, List<ReactNode> children) -
Creates a provider node.
const
Properties
-
children
→ List<
ReactNode> -
The provider's children.
final
-
context
→ ReactContext<
T> -
The context whose value is provided.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The value visible to descendants.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited