LazyNode<P> class
final
A portable node produced by LazyComponent.
- Inheritance
- Implemented types
Constructors
-
LazyNode(LazyComponentLoader<
P> load, P props, {String? key}) -
Creates a lazy node.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The optional React key.
final
-
load
→ LazyComponentLoader<
P> -
The loader used by the renderer.
final
- loaderIdentity → Function
-
The loader identity used to cache the React lazy component type.
no setteroverride
- nodeKey → String?
-
The optional React key.
no setteroverride
- props → P
-
The props passed to the loaded component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildWithErased(
Object builder) → ReactNode -
Builds the loaded Dart component through an erased boundary.
override
-
loadErased(
) → Future< Object> -
Loads the typed builder through an erased bridge.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited