Portal class final
A portal node rendered into a host container.
Constructors
Properties
-
children
→ List<
ReactNode> -
The children rendered through the portal.
final
- container → Object
-
The renderer-owned destination for the portal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The optional React key for this portal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited