ReactRuntimeCapabilities class final
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsContext → bool
-
final
- supportsEffects → bool
-
final
- supportsEvents → bool
-
final
- supportsLayoutEffects → bool
-
final
- supportsRefs → bool
-
final
- supportsSuspense → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- browser → const ReactRuntimeCapabilities
- server → const ReactRuntimeCapabilities