StateController<T> class
final
A snapshot of state together with a stable setter.
The value is the state observed during the current render. Calling set schedules the next render through the active renderer.
Constructors
-
StateController(T value, StateSetter<
T> set) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
set
→ StateSetter<
T> -
Sets the next state value.
final
- value → T
-
The current render's state value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited